import random
import re
import string
from functools import lru_cache

from django.http import HttpResponse, HttpResponseRedirect
from django.template import loader

SUCCESS_COOKIE_KEY = "success_message"
ERROR_COOKIE_KEY = "error_message"


def redirect(path, cookies={}):
    resp = HttpResponseRedirect(path)

    # add cookies
    for key in cookies:
        resp.set_cookie(key, cookies[key])

    return resp


def render(
    request,
    template_name=None,
    context={},
    content_type=None,
    status=None,
    using=None,
    **kwargs,
):
    """
    Return a HttpResponse whose content is filled with the result of calling
    django.template.loader.render_to_string() with the passed arguments.
    """
    # set global context values
    c = {
        "title": "",
        "meta": {
            "description": "A recognition system for your team.",
            "keywords": "detect, recognise, facial, worker, facial worker, detection, team, id, recogniser, ID My Team, idmy.team",
        },
        "logged_in": request.user.is_authenticated,
        **request.COOKIES,
        **kwargs,
    }

    content = loader.render_to_string(
        template_name, {**c, **context}, request, using=using
    )
    resp = HttpResponse(content, content_type, status)

    # remove flash success cookie
    resp.set_cookie(SUCCESS_COOKIE_KEY)
    resp.set_cookie(ERROR_COOKIE_KEY)

    return resp


@lru_cache()
def is_valid_email(email) -> bool:
    if len(email) <= 3:
        return False
    email_regex = "^\w+([\.-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,3})+$"
    return bool(re.search(email_regex, email))


def random_str(length):
    return "".join(
        random.choice(string.ascii_letters + string.digits) for _ in range(length)
    )


@lru_cache()
def kb_to_b(kb: int) -> int:
    return kb * 1024



import pytest

from idmyteam.idmyteam.structs import *


def test_TrainJob_val():
    tj = ErrorWSStruct("foo")
    assert tj.dict() == {
        "message": '{"type": 1, "message": "foo"}',
        "type": "chat_message",
    }


def test_missing_enum():
    with pytest.raises(ValueError):
        assert ErrorWSStruct.Type("notatype")


def test_ws_struct():
    ts = DeletedModelWSStruct("gi")
    assert ts.dict() == {
        "message": '{"type": 8, "message": "gi"}',
        "type": "chat_message",
    }



import inspect
import json
from enum import Enum
from typing import TypedDict, List, Tuple


class Struct:
    def dict(self) -> dict:
        values = {}
        for i, v in inspect.getmembers(self):
            if (
                not inspect.ismethod(v)
                and not inspect.isclass(v)
                and not i.startswith("_")
            ):
                values[i] = self.__getattribute__(i)
        return values


class WSStruct(Struct):
    class Type(int, Enum):
        ERROR = 1
        TRAINED = 2
        DELETE_IMAGE = 3
        CLASSIFICATION = 4
        INVALID_CLASSIFICATION = 5
        NO_MODEL = 6
        HAS_MODEL = 7
        DELETED_MODEL = 8

    type = "chat_message"
    _type: Type

    def __init__(self, message=""):
        self.message = json.dumps({"type": self._type, "message": message})


class ErrorWSStruct(WSStruct):
    _type = WSStruct.Type.ERROR


class DeleteImageWSStruct(WSStruct):
    _type = WSStruct.Type.DELETE_IMAGE


class NoModelWSStruct(WSStruct):
    _type = WSStruct.Type.NO_MODEL


class HasModelWSStruct(WSStruct):
    _type = WSStruct.Type.HAS_MODEL


class DeletedModelWSStruct(WSStruct):
    _type = WSStruct.Type.DELETED_MODEL


class InvalidClassificationWSStruct(WSStruct):
    _type = WSStruct.Type.INVALID_CLASSIFICATION


class FaceCoordinates(TypedDict):
    x: int
    y: int
    width: int
    height: int
    score: float
    is_manual: bool


class TrainedWSStruct(WSStruct):
    _type = WSStruct.Type.TRAINED

    def __init__(self, num_trained_classes: List[Tuple[int, int]]):
        super().__init__()
        self.num_trained_classes = num_trained_classes


class ClassificationWSStruct(WSStruct):
    _type = WSStruct.Type.CLASSIFICATION

    def __init__(
        self,
        coordinates: FaceCoordinates,
        member_id: int,
        score: float,
        file_name: str,
    ):
        super().__init__()
        self.coordinates = coordinates
        self.member_id = member_id
        self.score = score
        self.file_name = file_name



import os
from os.path import dirname, abspath

from django import template
from django.utils.safestring import mark_safe

register = template.Library()


@register.simple_tag
def define(val=None):
    return val


@register.simple_tag
def include_file(file_name):
    file = open(file_name).read()
    return mark_safe(file)


@register.simple_tag
def get_logo():
    parent_dir = dirname(dirname(abspath(__file__)))
    svg_logo_path = os.path.join(parent_dir, "static/images/icon.svg")
    file = open(svg_logo_path).read()
    return mark_safe(file)



import setuptools
from idmyteam import __version__

setuptools.setup(
    version=__version__,
    name="idmyteam",
    description="Base django files for idmyteam-client and idmyteam-server",
    url="https://idmy.team/",
    author="Maximilian Mitchell",
    author_email="max@max.me.uk",
    license="BSD-3-Clause",
    include_package_data=True,
    packages=setuptools.find_packages(),
)



from django import forms
from django.template.loader import get_template
from django import template
from django.forms.fields import DateTimeField, DateField
from django.http import QueryDict

register = template.Library()


@register.filter
def materializecss(element, options={}):
    # Set default values if none of them are set
    label_cols = "s12"
    icon = ""

    if options:
        # Split options string into a list of arguments
        arguments = [arg.strip() for arg in options.split(",")]

        # Check the first argument to see if it's of form argument=value
        if "=" not in arguments[0]:
            # If not, it's a custom size, so use that
            label_cols = arguments[0]
            # Remove this from the arguments list
            arguments.pop(0)

        # Join the remaining arguments into a querystring for easy parsing
        options = "&".join(arguments)
        qs = QueryDict(options)
        # Check to see if a custom size was passed in this fashion and if so prefer it
        if qs.get("custom_size"):
            label_cols = qs.get("custom_size")
        # Get icon if it's been set
        icon = qs.get("icon", default="")

    markup_classes = {
        "label": label_cols,
        "value": "",
        "single_value": "",
        "icon": icon,
    }
    return render(element, markup_classes)


def _add_input_classes_widget(widget, field_errors):
    if _is_multi_widget(widget):
        for subwidget in widget.widgets:
            _add_input_classes_widget(subwidget, field_errors)
    elif (
        not _is_checkbox_widget(widget)
        and not _is_multiple_checkbox_widget(widget)
        and not _is_radio_widget(widget)
        and not _is_file_widget(widget)
    ):
        classes = widget.attrs.get("class", "")
        classes += " validate"
        widget.attrs["class"] = classes


def add_input_classes(field):
    _add_input_classes_widget(field.field.widget, field.errors)


def render(element, markup_classes):
    element_type = element.__class__.__name__.lower()

    # Get the icon set setting
    icon_set = "default"

    if element_type == "boundfield":
        add_input_classes(element)
        template = get_template("materializecssform/field.html")
        context = {"field": element, "classes": markup_classes, "icon_set": icon_set}
    else:
        has_management = getattr(element, "management_form", None)
        if has_management:
            for form in element.forms:
                for field in form.visible_fields():
                    add_input_classes(field)

            template = get_template("materializecssform/formset.html")
            context = {
                "formset": element,
                "classes": markup_classes,
                "icon_set": icon_set,
            }
        else:
            for field in element.visible_fields():
                add_input_classes(field)

            template = get_template("materializecssform/form.html")
            context = {"form": element, "classes": markup_classes, "icon_set": icon_set}

    return template.render(context)


def _is_checkbox_widget(widget):
    return isinstance(widget, forms.CheckboxInput)


def _is_multiple_checkbox_widget(widget):
    return isinstance(widget, forms.CheckboxSelectMultiple)


def _is_radio_widget(widget):
    return isinstance(widget, forms.RadioSelect)


def _is_file_widget(widget):
    return isinstance(widget, forms.FileInput)


def _is_multi_widget(widget):
    return isinstance(widget, forms.MultiWidget)


@register.filter
def is_checkbox(field):
    return isinstance(field.field.widget, forms.CheckboxInput)


@register.filter
def is_textarea(field):
    return isinstance(field.field.widget, forms.Textarea)


@register.filter
def is_multiple_checkbox(field):
    return isinstance(field.field.widget, forms.CheckboxSelectMultiple)


@register.filter
def is_radio(field):
    return isinstance(field.field.widget, forms.RadioSelect)


@register.filter
def is_date_input(field):
    return isinstance(field.field, DateField)


@register.filter
def is_datetime_input(field):
    return isinstance(field.field, DateTimeField)


@register.filter
def is_file(field):
    return isinstance(field.field.widget, forms.FileInput)


@register.filter
def is_select(field):
    return isinstance(field.field.widget, forms.Select)


@register.filter
def is_select_multiple(field):
    return isinstance(field.field.widget, forms.SelectMultiple)


@register.filter
def is_captcha(field):
    return "captcha.widgets.ReCaptchaV2Invisible" in str(type(field.field.widget))


@register.filter
def is_required(field):
    return bool(field.field.required)
